==> dl.php?src=linea21_1_8.zip: linea21/languages/en/define.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$culture = array( 'en' => array( 'Language' => 'English'));

$l10n_links = array ('en' => array(
    					'home'=> array ('linkvalue' => 'home', 'accesskey' => '1', 'title' => 'home', 'desc'=>'Go to the Home page', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'project', 'accesskey' => 'a', 'title' => 'projects', 'desc'=>'Sustainable Development projects', 'alias'=> false, 'template'=>'publication'),
							'project-archives'=> array ('linkvalue' => 'project-archives', 'title' => 'projects', 'desc'=>'Sustainable Development projects', 'alias'=> 'project', 'template'=>'publication'),
    					'news'=> array ('linkvalue' => 'news', 'accesskey' => 'n', 'title' => 'news', 'desc'=>'News', 'alias'=> false, 'template'=>'publication'),
    					'news-archives'=> array ('linkvalue' => 'news-archives', 'title' => 'news archives', 'desc'=>'News archives', 'alias'=> 'news', 'template'=>'publication'),
							'newsletter'=> array ('linkvalue' => 'newsletter', 'title' => 'newsletters', 'accesskey' => 'j', 'desc'=>'access to newsletters', 'alias'=> false, 'template'=>'newsletter'),
							'page'=> array ('linkvalue' => 'page', 'title' => 'page', 'desc'=>'page', 'alias'=> false, 'template'=>'page'),
    					'report'=> array ('linkvalue' => 'report', 'title' => 'Workgroup report', 'desc'=>'See the workgroup report', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'report-part', 'title' => 'Workgroup report detail', 'desc'=>'See the workgroup report part', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'directory', 'accesskey' => 'y', 'title' => 'directory', 'desc'=>'Sustainable Development organisations directory', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'directory-detail', 'title' => 'Organisations Directory', 'desc'=>'Sustainable Development organisations directory', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'directory-add', 'title' => 'Organisations Directory', 'desc'=>'Sustainable Development organisations directory', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'workgroup', 'accesskey' => 'w', 'title' => 'workgroups', 'desc'=>'access and involve into workroups', 'alias'=> false, 'template'=>'workshop'),
    					'workgroup-subscription'=> array ('linkvalue' => 'workgroup-subscription',  'accesskey' => 's', 'title' => 'get involved', 'desc'=>'Subscribe to workgroups', 'alias'=> false, 'template'=>'wg-subscription'),
    					'files'=> array ('linkvalue' => 'shared-files', 'title' => 'Access to shared files', 'desc'=>'Access to shared files', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'calendar'=> array ('linkvalue' => 'calendar', 'title' => 'Workgroup calendar', 'desc'=>'Workgroup calendar', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'topic-list', 'title' => 'Workgroup forum', 'desc'=>'Workgroup forum', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'topic', 'title' => 'Workgroup forum topics', 'desc'=>'Workgroup forum topics', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'post-update', 'title' => 'edit a message', 'desc'=>'edit a message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'topic-add', 'title' => 'add a new topic', 'desc'=>'add a new topic', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'post-add', 'title' => 'add a new message', 'desc'=>'add a new message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'publication', 'accesskey' => 'p', 'title' => 'publications', 'desc'=>'Thematic publications', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'publication-archives', 'title' => 'publications archives', 'desc'=>'Thematic publications archives', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'publication-part', 'title' => 'publication part', 'desc'=>'Thematic publication in detail', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'dashboard', 'accesskey' => 'd', 'title' => 'dashboard', 'desc'=>'Dashboard : indicators monitoring in real time', 'alias'=> false, 'template'=>'dashboard'),
              'dashboard-rules'=> array ('linkvalue' => 'dashboard-rules', 'title' => 'Indicator rules', 'desc'=>'Indicator rules', 'alias'=> 'dashboard', 'template'=>'dashboard'),
              'dashboard-assessment'=> array ('linkvalue' => 'dashboard-assessment', 'title' => 'Indicator assessment', 'desc'=>'Indicator assessment', 'alias'=> 'dashboard', 'template'=>'dashboard'),
              'dashboard-provider'=> array ('linkvalue' => 'dashboard-provider', 'title' => 'Indicator provider', 'desc'=>'Indicator provider', 'alias'=> 'dashboard', 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'user-prefs', 'accesskey' => 'u', 'title' => 'user preferences', 'desc'=>'Access your user preferences', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'logout', 'accesskey' => 'l', 'title' => 'se déconnecter', 'desc'=>'log-out', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'user-registration', 'accesskey' => 'c', 'title' => 'register', 'desc'=>'Register, create an account', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'user-profile', 'title' => 'user profile', 'desc'=>'See user profile', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'forgot-password'=> array ('linkvalue' => 'forgot-password', 'title' => 'Forgot your password?', 'desc'=>'Change your password', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'search'=> array ('linkvalue' => 'search', 'accesskey' => '4', 'title' => 'perform an advanced search', 'desc'=>'Perform an advanced search', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'search-results', 'title' => 'search results', 'desc'=>'Search results', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accessibility', 'accesskey' => '1', 'title' => 'Linea21 accessibility policy', 'desc'=>'Linea21 accessibility policy', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'all-report', 'title' => 'all workgroup reports', 'desc'=>'Workgroup reports', 'alias'=> 'workgroup', 'template'=>'workshop'),
              'user-all'=> array ('linkvalue' => 'all-users', 'title' => 'workgroup users', 'desc'=>'Workgroup users', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'subscribe-newsletter', 'title' => 'subscribe our newsletter', 'desc'=>'Subscribe our newsletter', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'change-css-style', 'title' => 'change CSS', 'desc'=>'change style & CSS', 'alias'=> false, 'template'=>'message'),
						  'contact'=> array ('linkvalue' => 'contact', 'accesskey' => 'z', 'title' => 'contact', 'desc'=>'access the contact form', 'alias'=> false, 'template'=>'message'),
							'comment-unsubscribe'=> array ('linkvalue' => 'comment-unsubscribe', 'accesskey' => '', 'title' => '', 'desc'=>'', 'alias'=> false, 'template'=>'message'),
							'contribute'=> array ('linkvalue' => 'contribute', 'accesskey' => '', 'title' => 'contribute', 'desc'=>'Give your opinion', 'alias'=> false, 'template'=>'contribute'),

));

$l10n_filters = array ('en' => array(
								'tag' => array('linkvalue' => 'tag', 'name' => 'tag', 'desc'=>'filter by tag', 'active' => 0),
    						'theme' => array('linkvalue' => 'theme', 'name' => 'theme', 'desc'=>'filter by theme', 'active' => 0),
                'priority' => array('linkvalue' => 'priority', 'name' => 'priority', 'desc'=>'filter by priority', 'active' => 0),
    						'scale' => array('linkvalue' => 'scale', 'name' => 'scale', 'desc'=>'filter by scale', 'active' => 0),
                'alpha' => array('linkvalue' => 'alpha', 'name' => 'alpha', 'desc'=>'filter by alphabetical order', 'active' => 0)
));
?>

==> dl.php?src=linea21_2_0_0.zip: linea21/languages/en/define.php <==
<?php
/**
 * @package linea21\languages\en
 * @author $Author$ - linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$culture = array( 'en' => array( 'Language' => 'English'));

$l10n_links = array ('en' => array(
    					'home'=> array ('linkvalue' => 'home', 'accesskey' => '1', 'title' => 'home', 'desc'=>'Go to the Home page', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'project', 'accesskey' => 'a', 'title' => 'projects', 'desc'=>'Sustainable Development projects', 'alias'=> false, 'template'=>'publication'),
							'project-archives'=> array ('linkvalue' => 'project-archives', 'title' => 'projects', 'desc'=>'Sustainable Development projects', 'alias'=> 'project', 'template'=>'publication'),
    					'news'=> array ('linkvalue' => 'news', 'accesskey' => 'n', 'title' => 'news', 'desc'=>'News', 'alias'=> false, 'template'=>'publication'),
    					'news-archives'=> array ('linkvalue' => 'news-archives', 'title' => 'news archives', 'desc'=>'News archives', 'alias'=> 'news', 'template'=>'publication'),
							'newsletter'=> array ('linkvalue' => 'newsletter', 'title' => 'newsletters', 'accesskey' => 'j', 'desc'=>'access to newsletters', 'alias'=> false, 'template'=>'newsletter'),
							'page'=> array ('linkvalue' => 'page', 'title' => 'page', 'desc'=>'page', 'alias'=> false, 'template'=>'page'),
    					'report'=> array ('linkvalue' => 'report', 'title' => 'Workgroup report', 'desc'=>'See the workgroup report', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'report-part', 'title' => 'Workgroup report detail', 'desc'=>'See the workgroup report part', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'directory', 'accesskey' => 'y', 'title' => 'directory', 'desc'=>'Sustainable Development organisations directory', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'directory-detail', 'title' => 'Organisations Directory', 'desc'=>'Sustainable Development organisations directory', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'directory-add', 'title' => 'Organisations Directory', 'desc'=>'Sustainable Development organisations directory', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'workgroup', 'accesskey' => 'w', 'title' => 'workgroups', 'desc'=>'access and involve into workroups', 'alias'=> false, 'template'=>'workshop'),
						'workgroup-archives'=> array ('linkvalue' => 'workgroup-archives', 'title' => 'workgroups', 'desc'=>'access and involve into workroups', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'workgroup-subscription'=> array ('linkvalue' => 'workgroup-subscription',  'accesskey' => 's', 'title' => 'get involved', 'desc'=>'Subscribe to workgroups', 'alias'=> false, 'template'=>'wg-subscription'),
    					'files'=> array ('linkvalue' => 'shared-files', 'title' => 'Access to shared files', 'desc'=>'Access to shared files', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'calendar'=> array ('linkvalue' => 'calendar', 'title' => 'Workgroup calendar', 'desc'=>'Workgroup calendar', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'topic-list', 'title' => 'Workgroup forum', 'desc'=>'Workgroup forum', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'topic', 'title' => 'Workgroup forum topics', 'desc'=>'Workgroup forum topics', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'post-update', 'title' => 'edit a message', 'desc'=>'edit a message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'topic-add', 'title' => 'add a new topic', 'desc'=>'add a new topic', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'post-add', 'title' => 'add a new message', 'desc'=>'add a new message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'publication', 'accesskey' => 'p', 'title' => 'publications', 'desc'=>'Thematic publications', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'publication-archives', 'title' => 'publications archives', 'desc'=>'Thematic publications archives', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'publication-part', 'title' => 'publication part', 'desc'=>'Thematic publication in detail', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'dashboard', 'accesskey' => 'd', 'title' => 'dashboard', 'desc'=>'Dashboard : indicators monitoring in real time', 'alias'=> false, 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'user-prefs', 'accesskey' => 'u', 'title' => 'user preferences', 'desc'=>'Access your user preferences', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'logout', 'accesskey' => 'l', 'title' => 'se déconnecter', 'desc'=>'log-out', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'user-registration', 'accesskey' => 'c', 'title' => 'register', 'desc'=>'Register, create an account', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'user-profile', 'title' => 'user profile', 'desc'=>'See user profile', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'forgot-password'=> array ('linkvalue' => 'forgot-password', 'title' => 'Forgot your password?', 'desc'=>'Change your password', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'search'=> array ('linkvalue' => 'search', 'accesskey' => '4', 'title' => 'perform an advanced search', 'desc'=>'Perform an advanced search', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'search-results', 'title' => 'search results', 'desc'=>'Search results', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accessibility', 'accesskey' => '1', 'title' => 'Linea21 accessibility policy', 'desc'=>'Linea21 accessibility policy', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'all-report', 'title' => 'all workgroup reports', 'desc'=>'Workgroup reports', 'alias'=> 'workgroup', 'template'=>'workshop'),
              'user-all'=> array ('linkvalue' => 'all-users', 'title' => 'workgroup users', 'desc'=>'Workgroup users', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'subscribe-newsletter', 'title' => 'subscribe our newsletter', 'desc'=>'Subscribe our newsletter', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'change-css-style', 'title' => 'change CSS', 'desc'=>'change style & CSS', 'alias'=> false, 'template'=>'message'),
						  'contact'=> array ('linkvalue' => 'contact', 'accesskey' => 'z', 'title' => 'contact', 'desc'=>'access the contact form', 'alias'=> false, 'template'=>'message'),
							'comment-unsubscribe'=> array ('linkvalue' => 'comment-unsubscribe', 'accesskey' => '', 'title' => '', 'desc'=>'', 'alias'=> false, 'template'=>'message'),
							'contribute'=> array ('linkvalue' => 'contribute', 'accesskey' => '', 'title' => 'contribute', 'desc'=>'Give your opinion', 'alias'=> false, 'template'=>'contribute'),

));

$l10n_filters = array ('en' => array(
								'tag' => array('linkvalue' => 'tag', 'name' => 'tag', 'desc'=>'filter by tag', 'active' => 0),
    						'level' => array('linkvalue' => 'level', 'name' => 'level', 'desc'=>'filter by level', 'active' => 0),
                'priority' => array('linkvalue' => 'priority', 'name' => 'priority', 'desc'=>'filter by priority', 'active' => 0),
    						'scale' => array('linkvalue' => 'scale', 'name' => 'scale', 'desc'=>'filter by scale', 'active' => 0),
                'alpha' => array('linkvalue' => 'alpha', 'name' => 'alpha', 'desc'=>'filter by alphabetical order', 'active' => 0)
));
?>
